==> php82-nextcloud-26.0.5.tgz: share/nextcloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir a compartición remota {name} de {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contrasinal da compartición remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "Couldn't establish a federated share." : "Non foi posíbel estabelecer unha compartición federada",
    "Couldn't establish a federated share, maybe the password was wrong." : "Non foi posíbel estabelecer unha compartición federada, é probábel que o contrasinal sexa erróneo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Enviouse a solicitude dunha compartición federada, Vde. recibirá unha notificación. Comprobe as súas notificacións.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Non foi posíbel estabelecer unha compartición federada, semella que o servidor  federar é antigo de máis (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Non está permitido enviar unha compartición de grupos federados  dende este servidor.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Fallou a compartición de %1$s por mor de que este elemento xa foi compartido co usuario %2$s",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
    "Federated shares require read permissions" : "As comparticións federadas precisan permisos de lectura",
    "File is already shared with %s" : "O ficheiro xa está a ser compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Produciuse un fallo ao compartir %1$s Non foi posíbel atopar %2$s, quizais haxa un problema de conexión co servidor  ou emprega un certificado autoasinado.",
    "Could not find share" : "Non foi posíbel atopar a compartición",
    "Federated sharing" : "Compartición federada",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vde. recibiu {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Vde. recibiu {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "Sharing" : "Compartindo",
    "Federated file sharing" : "Compartición federada de ficheiros",
    "Provide federated file sharing across servers" : "Fornece a compartición federada de ficheiros entre servidores",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Axuste a forma como as persoas poden compartir entre servidores. Isto inclúe tamén as comparticións entre usuarios deste servidor se están a usar a compartición federada.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitirlle aos usuarios deste servidor enviar comparticións a outros servidores (esta opción tamén permite o acceso de WebDAV a comparticións públicas)",
    "Allow users on this server to receive shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións doutros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permitirlle aos usuarios deste servidor enviar comparticións a grupos noutros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións de grupos dende outros servidores",
    "Search global and public address book for users" : "Buscar usuarios nos cadernos de enderezos globais e públicos",
    "Allow users to publish their data to a global and public address book" : "Permitirlle aos usuarios publicar os seus datos nun caderno de  enderezos global e público",
    "Unable to update federated files sharing config" : "Non é posíbel actualizar a configuración de uso compartido de ficheiros federados",
    "Federated Cloud" : "Nube federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode compartir con calquera persoa que empregue servidores Nextcloud, ou outro servidor ou  servizo compatíbel co Open Cloud Mesh (OCM)! Simplemente, introduza o seu ID de nube federada no diálogo de compartir. É algo como persona@cloud.exemplo.com",
    "Your Federated Cloud ID:" : "ID da súa nube federada:",
    "Share it so your friends can share files with you:" : "Compártao para que as súas amizades poidan compartir ficheiros con Vde.:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Engadir ao seu sitio web",
    "Share with me via Nextcloud" : "Comparte comigo a través de Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparte comigo a través do meu #Nextcloud Federated Cloud ID, ver {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparte comigo a través do meu ID da nube federada de #Nextcloud",
    "Cloud ID copied to the clipboard" : "O identificador de nube (Cloud ID) (foi copiado no portapapeis",
    "Copy to clipboard" : "Copiar no portapapeis.",
    "Clipboard is not available" : "O portapapeis non está dispoñíbel",
    "Copied!" : "Copiado!",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Vde. recibiu «%3$s» como un elemento compartido remoto de %4$s (%1$s) (de parte de %5$s (%2$s))",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Vde. recibiu «%3$s» como un elemento compartido remoto de %4$s (%1$s)",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Comparte comigo a través do meu ID da nube federada de #Nextcloud , vexa %s"
},
"nplurals=2; plural=(n != 1);");

==> php82-nextcloud-28.0.6.tgz: share/nextcloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir a compartición remota {name} de {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contrasinal da compartición remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "Couldn't establish a federated share." : "Non foi posíbel estabelecer unha compartición federada",
    "Couldn't establish a federated share, maybe the password was wrong." : "Non foi posíbel estabelecer unha compartición federada, é probábel que o contrasinal sexa erróneo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Enviouse a solicitude dunha compartición federada, Vde. recibirá unha notificación. Comprobe as súas notificacións.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Non foi posíbel estabelecer unha compartición federada, semella que o servidor  federar é antigo de máis (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Non está permitido enviar unha compartición de grupos federados  dende este servidor.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Produciuse un erro ao compartir %1$s porque este elemento xa está compartido coa conta %2$s",
    "Not allowed to create a federated share to the same account" : "Non se permite crear un recurso compartido federado na mesma conta",
    "Federated shares require read permissions" : "As comparticións federadas precisan permisos de lectura",
    "File is already shared with %s" : "O ficheiro xa está a ser compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Produciuse un fallo ao compartir %1$s Non foi posíbel atopar %2$s, quizais haxa un problema de conexión co servidor  ou emprega un certificado autoasinado.",
    "Could not find share" : "Non foi posíbel atopar a compartición",
    "Federated sharing" : "Compartición federada",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vde. recibiu {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Vde. recibiu {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "Sharing" : "Compartindo",
    "Federated file sharing" : "Compartición federada de ficheiros",
    "Provide federated file sharing across servers" : "Fornece a compartición federada de ficheiros entre servidores",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Axusta a forma en que as persoas poden compartir entre servidores. Isto inclúe tamén as accións compartidas entre as persoas deste servidor se están a utilizar compartición federada.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitir que as persoas deste servidor envíen recursos compartidos a outros servidores (esta opción tamén permite o acceso de WebDAV aos recursos compartidos públicos)",
    "Allow people on this server to receive shares from other servers" : "Permitir que as persoas deste servidor reciban recursos compartidos doutros servidores",
    "Allow people on this server to send shares to groups on other servers" : "Permitir que as persoas deste servidor envíen recursos compartidos a grupos doutros servidores",
    "Allow people on this server to receive group shares from other servers" : "Permitir que as persoas deste servidor reciban comparticións grupais doutros servidores",
    "Search global and public address book for people" : "Busca a axenda de enderezos público e global para persoas",
    "Allow people to publish their data to a global and public address book" : "Permitir que as persoas publiquen os seus datos nunha axenda de enderezos pública e global",
    "Unable to update federated files sharing config" : "Non é posíbel actualizar a configuración de uso compartido de ficheiros federados",
    "Federated Cloud" : "Nube federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode compartir con calquera persoa que empregue servidores Nextcloud, ou outro servidor ou  servizo compatíbel co Open Cloud Mesh (OCM)! Simplemente, introduza o seu ID de nube federada no diálogo de compartir. É algo como persona@cloud.example.com",
    "Your Federated Cloud ID:" : "ID da súa nube federada:",
    "Share it so your friends can share files with you:" : "Compártao para que as súas amizades poidan compartir ficheiros con Vde.:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Engadir ao seu sitio web",
    "Share with me via Nextcloud" : "Comparte comigo a través de Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparte comigo a través do meu #Nextcloud Federated Cloud ID, ver {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparte comigo a través do meu ID da nube federada de #Nextcloud",
    "Cloud ID copied to the clipboard" : "O identificador de nube (Cloud ID) (foi copiado no portapapeis",
    "Copy to clipboard" : "Copiar no portapapeis.",
    "Clipboard is not available" : "O portapapeis non está dispoñíbel",
    "Copied!" : "Copiado!",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Fallou a compartición de %1$s por mor de que este elemento xa foi compartido co usuario %2$s",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Axuste a forma como as persoas poden compartir entre servidores. Isto inclúe tamén as comparticións entre usuarios deste servidor se están a usar a compartición federada.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitirlle aos usuarios deste servidor enviar comparticións a outros servidores (esta opción tamén permite o acceso de WebDAV a comparticións públicas)",
    "Allow users on this server to receive shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións doutros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permitirlle aos usuarios deste servidor enviar comparticións a grupos noutros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións de grupos dende outros servidores",
    "Search global and public address book for users" : "Buscar usuarios nos cadernos de enderezos globais e públicos",
    "Allow users to publish their data to a global and public address book" : "Permitirlle aos usuarios publicar os seus datos nun caderno de  enderezos global e público"
},
"nplurals=2; plural=(n != 1);");
